package com.theitbulls.customviewex;

import android.content.Context;
import android.graphics.Canvas;
import android.graphics.Color;
import android.graphics.Paint;
import android.os.Build;
import android.util.AttributeSet;
import android.view.MotionEvent;
import android.view.View;
import android.widget.Toast;

import androidx.annotation.Nullable;

public class SwitchButton extends View implements View.OnTouchListener {
    private boolean on;

    public SwitchButton(Context context, @Nullable AttributeSet attrs) {
        super(context, attrs);

        setOnTouchListener(this);
    }

    @Override
    protected void onDraw(Canvas canvas) {
        Paint paint = new Paint();

        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.LOLLIPOP) {
            paint.setColor(Color.BLUE);
            canvas.drawRoundRect(0, 0, getWidth(), getHeight(), 10, 10, paint);

            paint.setColor(Color.WHITE);
            canvas.drawRoundRect(5, 5, getWidth() - 5, getHeight() - 5, 10, 10, paint);
        } else {
            paint.setColor(Color.BLUE);
            canvas.drawRect(0, 0, getWidth(), getHeight(), paint);

            paint.setColor(Color.WHITE);
            canvas.drawRect(5, 5, getWidth() - 5, getHeight() - 5, paint);
        }

        int radius = ((getHeight() - 10) >> 1) - 20;
        if (!on) {
            paint.setColor(Color.RED);
            canvas.drawCircle(getWidth() - radius - 10, getHeight() >> 1, radius, paint);
        } else {
            paint.setColor(Color.GREEN);
            canvas.drawCircle(radius + 10, getHeight() >> 1, radius, paint);
        }
    }

    @Override
    public boolean onTouch(View view, MotionEvent motionEvent) {
        int left = (int) motionEvent.getX();
        int top = (int) motionEvent.getY();

        if (motionEvent.getAction() == MotionEvent.ACTION_UP) {
            on = !on;
            postInvalidate();

            Toast.makeText(getContext(), "OnTouchEvent Clicked on left: " + left + ", top: " + top + " of SwitchButton", Toast.LENGTH_SHORT).show();
            return true;
        }
        return false;
    }

    /*@Override
    protected void onMeasure(int widthMeasureSpec, int heightMeasureSpec) {
        super.onMeasure(widthMeasureSpec, heightMeasureSpec);

        // these width and height would be on your calculation
        setMeasuredDimension(220, 110);
    }*/
}
